@@ -1,7 +1,7 @@
 package String::Elide::Lines;
 
-our $DATE = '2017-01-28'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-29'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -143,7 +143,7 @@ sub elide {
             my $idx = $high_indexes[$i];
             my $part_len = @{ $parts[$idx] };
             my $to_elide = $must_elide_total_len_after_this[$#high_indexes - $i] -
-                $tot_already_elided + $tot_still_to_elide;
+                $tot_already_elided;
             if ($to_elide <= 0) {
                 # leave this part alone
             } elsif ($part_len <= $to_elide) {
@@ -182,7 +182,7 @@ String::Elide::Lines - Elide lines from a string, with options
 
 =head1 VERSION
 
-This document describes version 0.002 of String::Elide::Lines (from Perl distribution String-Elide-Lines), released on 2017-01-28.
+This document describes version 0.003 of String::Elide::Lines (from Perl distribution String-Elide-Lines), released on 2017-01-29.
 
 =head1 SYNOPSIS
 
